package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.38.2 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.38.2) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@$!`0````````````,`*``!````J18``#0```"4@0````0`!30`(``)
M`"@`&P`:``$``'`,?0``#'T```Q]```(````"`````0````$````!@```#0`
M```T````-````"`!```@`0``!`````0````#````5`$``%0!``!4`0``&0``
M`!D````$`````0````$````````````````````8?0``&'T```4`````$```
M`0```+Q]``"\C0``O(T``(P"``"@`@``!@`````0```"````Q'T``,2-``#$
MC0``"`$```@!```&````!`````0```!P`0``<`$``'`!``!$````1`````0`
M```$````4>5T9```````````````````````````!@```!````!2Y71DO'T`
M`+R-``"\C0``1`(``$0"```$`````0```"]L:6(O;&0M;&EN=7@M87)M:&8N
M<V\N,P`````$````%`````,```!'3E4`V^`((>L9E2\0=PL=XS=K%K$S<U<$
M````$`````$```!'3E4```````,````"`````````!$```!+````"`````@`
M```!D!`$)4`$@"B```6@AE"$@($``@LH!(PX@!)!B@``"$L```!,````3P``
M`%,```!4````70```%X```!?`````````&$```!B````8P```&0```!E````
M:````````````````:\TZ&[%WQ_.WD<M:W^:?"[%F[9V5#R4(/_D#M5DU'S9
M<5@<XD?&`4+ZUX>L2^/`NN.2?%COEWG"Y3\L^J%L8+(!BV^93\.;:PE#UF>O
MS&9"1=7LB0=PTS-BV^T5C"7,#3J7"W^IG)N^VE<;X*<""FL:GE"CX/M)````
M``````````````````````#,$0````````,`"P```````)`````````#`!8`
M!`(`````````````$@```'<"`````````````!(```!E`@`````````````2
M````U@(`````````````$@```)4"`````````````"(```#\`@``````````
M```1````B0,`````````````$@```!```````````````"````#_`0``````
M```````2````P0(`````````````$@```.,!`````````````!(```#I````
M```````````2````&`,`````````````$0```,\"`````````````!(```!-
M`0`````````````2````^0$`````````````$@```(<``````````````!(`
M``"K`@`````````````2````Y```````````````$@```+T!````````````
M`!(```"5`0`````````````2````!@,`````````````$@```-P!````````
M`````!(```!!`@`````````````2````/P$`````````````$@```,8`````
M`````````!$````-`0`````````````2````8P``````````````%@```#@"
M`````````````!(```"'`@`````````````1````>P$`````````````$@``
M`*L!`````````````!(```!H`0`````````````2````N0(`````````````
M$@```,T!`````````````!(```!T`0`````````````2````$0(`````````
M````$@```!L!`````````````!(````!```````````````@````(`(`````
M````````$@```*8!`````````````!(```#R`0`````````````2````A@$`
M````````````$0```%0``````````````!(```"D`@`````````````2````
ME@``````````````$@```-T"`````````````!(```!)`@`````````````2
M````H@``````````````$@```#0!`````````````!(````+`@``````````
M```2````L@(`````````````$@```/H``````````````!(```!&````````
M```````2````[@``````````````$@```%T!`````````````!(```!7`@``
M```````````2````TP``````````````$@```(X"`````````````!(```#(
M`@`````````````2````ZP$`````````````$@```"<"`````````````!(`
M``!V```````````````2````U`$`````````````$@```+,!````````````
M`!(```"W```````````````2````*P$`````````````$@```"P`````````
M`````"````#^`@`````````````1````]`(`````````````$@```.X"````
M`````````!(```#$`0`````````````2````I@,``%R0````````$``7`)(#
M``#1+0``S````!(`#0#*`P``(2<``-`$```2``T`<@(``-$4``#8`0``$@`-
M`%@#``"!'0``!````!(`#0!I`P``2)`````````0`!<`5@0``(4=``"P`0``
M$@`-`)0$``#Q*P``X`$``!(`#0!"!```2)`````````0`!<`L0,``#4?```D
M````$@`-`-<#``!1.0``Y````!(`#0#O`P``&#L```0````1``\`'@0``%R0
M````````$``7`",$``!<D````````!``%P!.!```A1P``#P````2``T`8P0`
M`#4F``#L````$@`-`'4$```=)```;````!(`#0"#!```B20``%0````2``T`
MX@,```"0````````$``6`+X#``!9'P``'`$``!(`#0">`P``2)`````````0
M`!8`%`0``$20```$````$0`6`.@#``"I%@```````!(`#0"+!```T3@``(``
M```2``T`Y`,```"0````````(``6`'<#```9)@``'````!(`#0"E`P``7)``
M```````0`!<`_@,``,$<``#`````$@`-`#@$```U.@``R@```!(`#0`K!```
M=2```*@#```2``T``%]?9VUO;E]S=&%R=%]?`%])5$U?9&5R96=I<W1E<E1-
M0VQO;F5486)L90!?251-7W)E9VES=&5R5$U#;&]N951A8FQE`%!E<FQ?<WES
M7W1E<FT`4&5R;%]S>7-?:6YI=#,`4$Q?8W5R<F5N=%]C;VYT97AT`%!E<FQ?
M871F;W)K7VQO8VL`<&5R;%]C;VYS=')U8W0`4&5R;%]G971?<W8`4&5R;%]C
M<F]A:U]N;V-O;G1E>'0`4&5R;%]S=E]S971P=FX`4$Q?9&]?=6YD=6UP`%!E
M<FQ?;F5W6%-?9FQA9W,`<&5R;%]F<F5E`%!E<FQ?;6=?<V5T`%!E<FQ?871F
M;W)K7W5N;&]C:P!097)L7W-V7W-E='!V`%!E<FQ?9W9?9F5T8VAP=@!P97)L
M7W)U;@!097)L7VYE=UA3`'!E<FQ?9&5S=')U8W0`8F]O=%]$>6YA3&]A9&5R
M`'!E<FQ?<&%R<V4`4&5R;%]S869E<WES;6%L;&]C`'!E<FQ?86QL;V,`4$Q?
M;65M;W)Y7W=R87``7U]S=&%C:U]C:&M?9F%I;`!E>&ET`&QS965K-C0`<F5A
M9&1I<C8T`'-T<F1U<`!C;&]S961I<@!O<&5N-C0`<W1R<F-H<@!U;FQI;FL`
M;65M;6]V90!S=')T;VL`<W1R;&5N`')M9&ER`')E860`<W1R<W1R`&UK9&ER
M`%]?=F9P<FEN=&9?8VAK`&=E='!I9`!?7VQS=&%T-C1?=&EM938T`')E861L
M:6YK`')E86QL;V,`7U]S<')I;G1F7V-H:P!?7V9P<FEN=&9?8VAK`%]?;&EB
M8U]S=&%R=%]M86EN`%]?<W1A=#8T7W1I;64V-`!S=&1E<G(`;65M8VAR`%]?
M8WAA7V9I;F%L:7IE`'-T<F-H<@!M96UC;7``;65M<V5T`&]P96YD:7(`9V5T
M=6ED`&%C8V5S<P!M96UC<'D`<W1R8VUP`%]?97)R;F]?;&]C871I;VX`86)O
M<G0`<W1R;F-M<`!?7V5N=FER;VX`7U]R96=I<W1E<E]A=&9O<FL`7U]S=&%C
M:U]C:&M?9W5A<F0`;&EB<&5R;"YS;RXU+C,X`&QI8F,N<V\N-@!L9"UL:6YU
M>"UA<FUH9BYS;RXS`'!A<E]C=7)R96YT7V5X96,`7U]B<W-?<W1A<G1?7P!G
M971?=7-E<FYA;65?9G)O;5]G971P=W5I9`!P87)?8VQE86YU<`!?961A=&$`
M7U]B<W-?96YD7U\`<&%R7V)A<V5N86UE`'!A<E]D:7)N86UE`'!A<E]M:W1M
M<&1I<@!S:&%?=7!D871E`%]?9&%T85]S=&%R=`!?24]?<W1D:6Y?=7-E9`!P
M87)?8W5R<F5N=%]E>&5C7W!R;V,`;7E?<&%R7W!L`%]E;F0`7U]E;F1?7P!P
M87)?:6YI=%]E;G8`<VAA7V9I;F%L`%]?8G-S7W-T87)T`'AS7VEN:70`<&%R
M7V9I;F1P<F]G`'!A<E]S971U<%]L:6)P871H`'!A<E]E;G9?8VQE86X`<&%R
M7V1I90!S:&%?:6YI=`!84U]);G1E<FYA;'-?4$%27T)/3U0`1TQ)0D-?,BXT
M`$=,24)#7S(N,S0```````````(``P`#``(``@`"``(``0`"``(``@`"``0`
M`@`!``(``0`"``$``@`"``(``@`"``$``0`!``$``@`"``$``@`!``(``@`"
M``(``0`!``(``@`"``$``0`"``$``@`"``$``0`"``(``0`!``$``0`"``$`
M`@`"``(``P`!``(``@`!``$``0`"``(``@`"``$``0`!``$``0`!``$``0`!
M``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!````
M`0`!`$0#```0````(````!1I:0T```0`J@0````````!``(`.@,``!``````
M````M)&6!@```P"T!```$````!1I:0T```(`J@0```````"\C0``%P```,"-
M```7````\(\``!<````$D```%P```!20```7````&)```!<````@D```%P``
M`"20```7````*)```!<````LD```%P```#"0```7````.)```!<````\D```
M%P```$20```7````R(\``!4'``#,CP``%0H``-"/```5#P``U(\``!41``#8
MCP``%1P``-R/```3'@``X(\``!4@``#DCP``%2D``.B/```5+0``[(\``!4W
M``#TCP``%4$``/B/```51@``_(\``!5'``#8C@``%@,``-R.```6!```X(X`
M`!8%``#DC@``%@8``.B.```6!P``[(X``!8)``#PC@``%@L``/2.```6#```
M^(X``!8-``#\C@``%@X```"/```6$```!(\``!82```(CP``%A,```R/```6
M%```$(\``!85```4CP``%A8``!B/```6%P``'(\``!88```@CP``%AD``"2/
M```6&@``*(\``!8;```LCP``%AT``#"/```6'P``-(\``!8A```XCP``%B(`
M`#R/```6(P``0(\``!8D``!$CP``%B4``$B/```6)@``3(\``!8G``!0CP``
M%B@``%2/```6*0``6(\``!8J``!<CP``%BL``&"/```6+```9(\``!8N``!H
MCP``%B\``&R/```6,```<(\``!8Q``!TCP``%C(``'B/```6,P``?(\``!8T
M``"`CP``%C4``(2/```6-@``B(\``!8X``",CP``%CD``)"/```6.@``E(\`
M`!8[``"8CP``%CP``)R/```6/0``H(\``!8^``"DCP``%C\``*B/```60```
MK(\``!9"``"PCP``%D,``+2/```61```N(\``!9%``"\CP``%D@``,"/```6
M20``Q(\``!9*```(0"WI00$`ZPB`O>@$X"WE!."?Y0[@C^`(\+[EY'P```#&
MC^('RHSBY/R\Y0#&C^('RHSBW/R\Y0#&C^('RHSBU/R\Y0#&C^('RHSBS/R\
MY0#&C^('RHSBQ/R\Y0#&C^('RHSBO/R\Y0#&C^('RHSBM/R\Y0#&C^('RHSB
MK/R\Y0#&C^('RHSBI/R\Y7A'_><`QH_B!\J,XIC\O.4`QH_B!\J,XI#\O.4`
MQH_B!\J,XHC\O.4`QH_B!\J,XH#\O.4`QH_B!\J,XGC\O.4`QH_B!\J,XG#\
MO.5X1_WG`,:/X@?*C.)D_+SE`,:/X@?*C.)<_+SE>$?]YP#&C^('RHSB4/R\
MY0#&C^('RHSB2/R\Y0#&C^('RHSB0/R\Y0#&C^('RHSB./R\Y0#&C^('RHSB
M,/R\Y0#&C^('RHSB*/R\Y0#&C^('RHSB(/R\Y0#&C^('RHSB&/R\Y0#&C^('
MRHSB$/R\Y0#&C^('RHSB"/R\Y0#&C^('RHSB`/R\Y0#&C^('RHSB^/N\Y0#&
MC^('RHSB\/N\Y0#&C^('RHSBZ/N\Y0#&C^('RHSBX/N\Y0#&C^('RHSBV/N\
MY0#&C^('RHSBT/N\Y0#&C^('RHSBR/N\Y0#&C^('RHSBP/N\Y0#&C^('RHSB
MN/N\Y0#&C^('RHSBL/N\Y0#&C^('RHSBJ/N\Y0#&C^('RHSBH/N\Y0#&C^('
MRHSBF/N\Y7A'_><`QH_B!\J,XHS[O.4`QH_B!\J,XH3[O.4`QH_B!\J,XGS[
MO.4`QH_B!\J,XG3[O.4`QH_B!\J,XFS[O.4`QH_B!\J,XF3[O.4`QH_B!\J,
MXES[O.4`QH_B!\J,XE3[O.4`QH_B!\J,XDS[O.4`QH_B!\J,XD3[O.4`QH_B
M!\J,XCS[O.4`QH_B!\J,XC3[O.4`QH_B!\J,XBS[O.4`QH_B!\J,XB3[O.4`
MQH_B!\J,XAS[O.4`QH_B!\J,XA3[O.4`QH_B!\J,X@S[O.4`QH_B!\J,X@3[
MO.4`QH_B!\J,XOSZO.4`````<+5/](!<K>L,#,SXR`]>38JP7DM]1%Y,S>D&
M$`:I!9('J`6J?$3K6!MH"9-/\``#__=,[U=*6$NB6`.2$4;C6`23&$8"\/3Z
M5$OC6!UX`"UCT!WN<"]*2P>8>T0;:,4<!#"P\8!/TEB2^-8S0_`#`X+XUC-T
MTH``__?L[DA)24H#1GE$!IQZ1`EH4&`@:)E@14D'FGE$V6!$20$J&&!Y1%E@
M9=TA'03K@@X#\0P,4?@$2TSX!$^.1?G1T1P\3``@`)`J1GQ$0_@A`#I)X&AY
M1/_W0.\`*#'0-TT(KGU$Z&C_]YKN!$8U2#%&>$0`\/+X0+,S2WM$V&C_]V;N
M__<>[S!*(DMZ1--8&F@)FUI`3_```S+1($8*L'"]__>0[BI*>D308#"S__=$
M[A9+'>YP+WM$&VC36(/XOE:,Y^!H__=&[\GGJ&@0L0'PVOO1YQ](,49X1`#P
MOOBH8``HR=#SYQM+'$AX1.-8`Y,91O_WS.X$(:/G`2#_]Y[N__<T[@"_KGH`
M`-AY``#D>0``!`$``-1Y```@`0``*`$```P!``#N>@``\GH``&0I``!6*0``
MM'H``&L&``"<>@``LB8``(1Z``#T>```6'H``.8E```<`0``T"<``$_P``M/
M\``.`KQJ1@2T`;3?^!B@!:.:1$_P``,(M`1(6O@``/_WFNW_]_#N^'<``"0!
M```4,)_E%""?Y0,PC^`"()/G``!2XQ[_+P$<___JX'<``!@!```&2`=+!TIX
M1'M$>D2#0@/0!4O36`.Q&$=P1P"_/GD``#QY``"^=P````$```A("4MX1`E*
M>T0;&GI$V0\!ZZ,!21`#T`5+TU@#L1A'<$<`OQ1Y```0>0``D'<``"P!```(
MM0I+"DI[1'I$&WAKN0E+TU@CL0A+>T08:/_W4.W_][__!DL!(GM$&G`(O=YX
M``!@=P``_````(IX``"^>```Q.<`ORWI^$-/](!<K>L,#,SXX`\?2X!&>T0`
M*#;0'DJ;6-/X`)"Y\0`/,=`%>`]&`"T8OSTM%+\!)0`E$]'9^`!`;+%.1BI&
M048@1O_W7.X0N6-=/2L0T%;X!$\`+/+1($:]Z/B#!485^`$_`"L8OSTK^=&E
MZP@%X>>FZPD&`34L1+80/F`@1KWH^(,$1N?G3$;EYQ!W```P`0``$+5/](!<
MK>L,#,SX@`\72IZP%TMI1GI$!$;36!MH'9-/\``#__<$[J"Y!)L#]'!#L_4@
M3QB_L_6`3PW0#4H,2WI$TU@::!V;6D!/\``#"]$>L!"]`"#QYP(A($;_]]SM
ML/J`\$`)Z>?_]P;M=G8```0!``!,=@``\+5/](!<K>L,#,SX:`\V2J&P-DMZ
M1--8&V@?DT_P``,0L0-X!$9;N3%*,$MZ1--8&F@?FUI`3_```U/1(;#PO?_W
M'.T%1@`H[M`H1O_WP.T`*#;0PWP`\1,&+BL"T7-X`"ORT,-\+BLRT"!&__<V
M[0=&,$;_]S+M.$0",/_W"NT<2T_P_S(!(7M$`98`E`9&__="[0*I,$;_]U3L
M`3`P1@70!IL#]'!#L_6`3Q?0__>V[#!&__=X["A&__>*[0`HR-$H1O_WHNT@
M1O_W>NRKYW-X+BO)T;-X`"NVT,7G__>/_^;G__>,[`!V```$`0``Z'4``&PB
M```MZ?!'3_2`7*WK#`S,^-@/5TJ"L%=+#$9Z1`5&W_A8@=-8^$0;:`&33_``
M`PMX/2L(OP$T($;_]];L:48&1BA&__?:_H%&`"A4T/_WS.R&0D?92DL`GUCX
M`X"_`"MX`"L8OSTK%+\!(P`C!]`K1A/X`2\`*AB_/2KYT5L;L!S8^`!@&$3_
M]XKL\%'HL=CX`#`H1ME9$/@!.PMP/2L8OP`K"=!*'!#X`3L11@+X`3L]*QB_
M`"OVT0I&/2,+<!3X`3L"^`$_`"OYT2U**DMZ1--8&F@!FUI`3_```T;1`K"]
MZ/"'"?'_.13X`3L)^`$_`"OYT>GG(4M8^`.`V/@`<#MH@[,[1E/X!"])1@GQ
M`0D`*OC1`S&)`!M*>D03:+NY"$8!(Q-@__<Z[()&`"C,T#E&3^J)!SI&__>T
MZ\CX`*#-^`"0"?$!"0`C2O@I,(;G.$;_]^[K@D;(^````"BTT$_JB0?LYYE&
M""'5Y__WSNL`OP1U```$`0``^G0``#`!``!0=```A'4``"WI\$%/](!<K>L,
M#,SX``!,^"`,#T8L22Q+K?6`77E$@K`&1@WU@%`$,`WQ!`C+6$#V_W)!1AMH
M`V!/\``#)$AX1/_WQ.L$'@?=`JUC'@7K`PP<^`0LZKG;N1E+'>YP#SI&,49[
M1!MHP%C_]ZKK&4H-]8!1%4L$,7I$TU@::`MH6D!/\``#&-$-]8!=`K"]Z/"!
M'$8B1B\A0$;_]SSL`"C;T`A('>YP7R-&0D9X1`!H,48H6/_W4NS9Y__W8NL`
MOT!T``#X<P``=G,```0!```\(```'',``#"U3_2`7*WK#`S,^.`/$TH=[G!/
M#TF%L!%(>D1Y1`EH$$L`)7M$$EA@6`])`Y)Y1/_WU.L(20U+>40):`Q*>T1Z
M1&!8"TD!E7E$`)/_]_#K!;`PO;!S``"4<P``HG(```@!```T8```AA\``'8B
M``"A#P``B!\```I*@K`*21WN<,]Z1`9("4MX1`!H4EA[1`=)7/@``'E$`9("
ML/_WG+M$<P``.G(```@!``#*7P``'A\``'"U3_2`7*WK#`S,^```K/6`7,SX
M``!,^"@,)$JM]0!=(TN&L'I$#?4`410Q`ZP-]8!6TU@0-AMH"V!/\``#__<\
MZQQ*`2$<2WI$S>D``GM$($9!\@$"__=:ZR!&3_2`4C%&__?NZ@0>N+\`)0K;
M8!S_]PKK!48HL2)&,4;_]Y3J`",K50U*#?4`40E+%#%Z1--8&F@+:%I`3_``
M`P31*$8-]0!=!K!PO?_WI.KD<0``!`$``/@>``#F'@``>G$``/_WGK\MZ?!/
M3_2`7*WK#`S,^```3/BP#%I*K?6$75I+@[!Z1`9&64@-]815#?$0"`0UTU@,
M1GA$048;:"M@3_```__W[_PO(05&,$;_]^SJP+%/2#%&>$3_]^C],$9-2@WU
MA%%(2P0Q>D336!IH"VA:0$_P``-`\(.`#?6$70.PO>CPCR!&__=0ZD-)>43_
M]RCK!$8`*-S0(W@-\8@*W_C\D*KQ!`?Y1``K2-`EL2%&*$;_]^[IN+,@1O_W
MJNI#'B-$@T:<0CZ_(Q@`(6`<`],*X)A"&7`#T!/X`2TO*OC0($;_]Y;J@T8P
M1O_WDNI81`$PL/6`7ZS2*4@!(4M&3_2`4GA$`)3-Z0$&.$;_]Y[J048X1O_W
ML.DPN5KX:#P#]'!#L_4`3Q?0'DD`('E$__?8Z@1&`"B,T"-X`"NVT=6Q*W@N
M*P30&$Q/\`$+?$3+YVMX`"OHT/;G`2$X1O_WNNH`*.'1$4@Y1GA$__=?_3A&
M__?:Z7/G#DQ/\`$+?$2SY__WV.DF<0``!`$``%(>```^'@``X'```!@>```"
M'@``KAT``'@=```X'0``+!T```@=```0M4_T@%RMZPP,S/CX#R\A!$;_]YCJ
M`+%$'"!&O>@00/_WIKGPM4_T@%RMZPP,S/@``$SX(`P[2JWU@%TZ2X.P>D0-
M]8!1!#'36!MH"V!/\``#`"@\T`-X!48`*SC0__?^Z4(<!$:R]8!?1]@!KRE&
M.$;_]V#I8QX[1)]""](X&0WQ!0(`(0+@D$(!<`/0$/@!/2\K^-`O(3A&__=4
MZGBSN$*$OP`C`W`X1O_W9.D?2@WU@%$<2P0Q>D336!IH"VA:0$_P``,KT0WU
M@%T#L/"]%TH-]8!1%$L$,7I$TU@::`MH6D!/\``#&M$22'A$#?6`70.PO>CP
M0/_W.KD`(-;G#4H-]8!1"$L$,7I$TU@::`MH6D!/\``#`M$(2'A$YN?_]R[I
M5&\```0!``#<;@``NFX``.0;``"*;@``M!L``'"U3_2`7*WK#`S,^.@/S$J"
ML,Q+;$9Z1,M.S$U^1--8?40;:`&33_```R%&,$;_]W_[L+'&2P"8ZU@9:`'K
M@`-::$'X("``*N_0!#-::$/X!"L`*OK1(48P1O_W:?L`*.C1O$Y^1"%&,$;_
M]V'[L+&W2P"8ZU@9:`'K@`-::$'X("``*N_0!#-::$/X!"L`*OK1(48P1O_W
M2_L`*.C1KDY^1"%&,$;_]T/[L+&H2P"8ZU@9:`'K@`-::$'X("``*N_0!#-:
M:$/X!"L`*OK1(48P1O_W+?L`*.C1H$Y^1"%&,$;_]R7[L+&92P"8ZU@9:`'K
M@`-::$'X("``*N_0!#-::$/X!"L`*OK1(48P1O_W#_L`*.C1DDY^1"%&,$;_
M]P?[L+&*2P"8ZU@9:`'K@`-::$'X("``*N_0!#-::$/X!"L`*OK1(48P1O_W
M\?H`*.C1A$Y^1"%&,$;_]^GZL+%[2P"8ZU@9:`'K@`-::$'X("``*N_0!#-:
M:$/X!"L`*OK1(48P1O_WT_H`*.C1=DY^1"%&,$;_]\OZL+%L2P"8ZU@9:`'K
M@`-::$'X("``*N_0!#-::$/X!"L`*OK1(48P1O_WM?H`*.C1:$Y^1"%&,$;_
M]ZWZL+%=2P"8ZU@9:`'K@`-::$'X("``*N_0!#-::$/X!"L`*OK1(48P1O_W
ME_H`*.C16DY^1"%&,$;_]X_ZL+%.2P"8ZU@9:`'K@`-::$'X("``*N_0!#-:
M:$/X!"L`*OK1(48P1O_W>?H`*.C13$Y^1"%&,$;_]W'ZL+$_2P"8ZU@9:`'K
M@`-::$'X("``*N_0!#-::$/X!"L`*OK1(48P1O_W6_H`*.C1/DY^1"%&,$;_
M]U/ZL+$P2P"8ZU@9:`'K@`-::$'X("``*N_0!#-::$/X!"L`*OK1(48P1O_W
M/?H`*.C1,$@A1GA$__<V^@%&&+$M2'A$__<T^RQ((49X1/_W*_H!1ABQ*DAX
M1/_W*?LI2"%&>$3_]R#Z`4:PL29(>$3_]Q[[)4H12WI$TU@::`&;6D!/\``#
M%=$A22)(>41X1`*PO>AP0/_W"[L?2"%&>$3_]P+Z`48`*.30'$AX1/_W__K?
MY_[W@.\^;@``!`$``*0;```T;@``,`$``&@;```T&P``!!L``-`:``"D&@``
M!!H``#@:```(&@``V!D``"`9``!J&0``1AD``&@9``!P&0``<AD``)X8``!4
M:P``T!H``-(8``!&&0``T!@```"U3_2`7*WK#`S,^/`/$TJ#L!-+:49Z1!)(
M>$336!MH`9-/\``#__>O^4"Q`'@`*!B_,"@,OP$@`""`\`$`"DH'2WI$TU@:
M:`&;6D!/\``#`M$#L%WX!/O^]Q[OEFH```0!``!"&```:FH```^T3_2`7`"U
MK>L,#,SX\`_?^##`@[`,2@2K_$0+20Q(>41<^`(@$F@!DD_P``)3^`0K`),(
M6`$A`&C^]TCO_R#^]USO)FH```0!```@:@``%`$``"WI\$=/\``,3_2`/JWK
M#`RLZPX.K/6`7,SX``#T1?G13O@X#*WU@#V&L#Y,`B$-]8`U?$04-0"1`"([
M20`C@$9A6`EH*6!/\``!_O?X[@$X8?$`!_H7@.H"`YL:F[)30)L:8NL"`L8:
M9^L"!P`O2]M/\`@)P/(!"0.M`"$R1CM&0$8`D?[WVNZQ\?\_"+^P\?\_0=!*
M1BE&0$;^]U[N0QPVT`<H)MD(."P8(]+?^'R@^D0"X`$\K$(<TP@B448@1O[W
M=NX`*/719!N@&4?KY'$72@WU@#042Q0T>D336!IH(VA:0$_P``,:T0WU@#T&
ML+WH\(>V]8`V9_$`![?Q_S\(OQ;U@#^XT4_P_S`!1M_G"$AX1/_W2O\'2'A$
M__=&__[W6NZZ:0``!`$``'AJ```2:0``%A<``/X6```(M4_T@%RMZPP,S/CX
M#_[W#.[^]_[M`+$`:`B]\+5/](!<K>L,#,SXT`\N2H>P+DL%1GI$+4X$J7Y$
MTU@P1AMH!9-/\``#__>A^!"Q`W@$1HNY)THD2WI$TU@::`6;6D!/\``#/-$C
M2"E&>$0'L+WH\$#_]X^Y*4;^]ZSM6+$>2AE+>D336!IH!9M:0$_P``,FT0>P
M\+TH1O[W;NX'1B!&_O=J[CA$`C#^]T+N$TM/\/\R`2%[1`&3$4L"E`1&>T0`
ME?[W>.X/2@=+>D336!IH!9M:0$_P``,$OR%&,$;%T/[WW.U^:```!`$``,`6
M``!::```CA8``"YH``!8%0``4A4``.9G```MZ?!/3_2`7*WK#`S,^.`.W_@X
M%+^PW_@X5"2OW_@T)'E$?42"1@7Q#`,%\1@,*JPP-8I8)D8-\9P)W_@<M!)H
M/9)/\``"#?$@")/H!P"'Z`<`^T2\Z`\`#\:<Z`,`AN@#`)7H!P")Z`<`_$A!
M1GA$__<(^""Q`W@%1@`K0/!I@?[W3NW^]T#M`"@`\)V`!F@`+@#PF8`P1O[W
MZNU```$P_O?"[3%X!48'D'FQW_BPD_E$*$8`D4M&`2%/\/\R`C7^]_3M%O@!
M'P`I\M'E2'A$`N!4^`0/B+%!1O[WT_\%1@`H]M`#>``K\]#_]Q?X`"COT"A&
M_O=([01&B+E7^`1+=+$C>``K`/`/@2!&__<&^``H\]`@1O[W..T$1@`H[=`@
M1O[WINT'G09&*$;^]Z#M!D0&\@1&,$;^]W;MRDL'1D_P_S)[1`*3R$L!(0.5
M>T0!D\=+`)1[1/[WJ.U/].!Q.$;^][CM`3`%T?[WFNT!:!$I0/#@@$%&.$;^
M]^CM!48`*#G0NTG:^``PNTI;^`$`>D0`EP$A`&C^][KM`":W2JQ+>D336!IH
M/9M:0$_P``-`\$:!,$8_L+WH\(_^]^3L!D8`*$#PLH!9^`0+6+%!1O[W6/\`
M*/?0`W@`*^[16?@$"P`H\]&F3@T@_O<>[5,A!49^1`>06><,FP/T<$.S]8!/
MO]$.G/[WC.R$0KK1#)O#\P@#L_7@?[31,$;^]P3M!D:82$%&>$3^]RS_`48`
M*`#PH8#:^```__<4^H%&`"@`\)F`2$;^]Q3M!$8#*`_9C4D$.$A$>43^]TKL
M0+D$+`#PV8!,1!3X!3PO*P#PTX"&2$%&>$3^]P7_(+$#>#`K&+\`*P;1`"%(
M1O[WR.P$1@`H<]%^27](>43?^/RA>$3?^/B1_O?R_]_X]('^]]3L?$M/\/\R
M`2%[1`.3>DOZ1`"7^41[1,WI`3!X2S!&^$1[1/[W[.P3X/[WXNP#:!$K%M'^
M][KL`36$1E-&(D8!(3!&S>D#6<WI`8P`E_[WUNQ/].!Q,$;^]^;L!$9#'./0
M.$;^]Q3L9D@Q1GA$_O>V_S!&__?W_3KG'$;YYO[WH.Q```$PM.9/2MKX`#!;
M^`(`S>D`<0$A6TH`:'I$_O?@["3G__??_5A*/DMZ1--8&F@]FUI`3_```VK1
M*$8_L+WH\$_^]P>\VO@`D&/G__<>_8!&L?$`"87;L/$*`D_P``II\0`#($8-
M\<`+S?@`H/[W+.P&(EE&($;^][3K!BA)T3":3_2&0\3R03.:0G_T:J^[^`0@
M1/)(4YI"?_1CK[CQ,@(@1FGQ``,RK<WX`*#^]PSL($8H(BE&_O>4ZR@H*=$R
M2P$A,DHP1GM$`9,Q2WI$`I4#DGM$3_#_,@"7C?CPH/[W3.Q\Y]KX!$``+#_T
M**\@1O[W)NP#*'_V(J\F200X($1Y1/[W7.L`*`B_H487Y_[WJ.LA2'A$__>.
M_(AG``#":```!`$``%9G``!Z%```6!4``-84``#8%```PA,``+H4```4`0``
MT!0```9F```.%```CA0``&84``#D$@``H!0``+H2```Z%```WA0``$(2``#H
M%```3!(``!@4``#.$0``VA(``$YD```8$0``HA,``-02``"2$@``AA(``'"U
M3_2`7*WK#`S,^.@/9$F"L&1*'>YP3WE$64MB2&Y&BEAX1#%&$F@!DD_P``)[
M1!MHY5B5^&@PA?AI,/[WNOT0L0-X,2M\T/_W'/I-2WM$&VCE6%5)*$8#(P$B
M>43^]XCK!49PL0)I1TM[1!MH$6A/2N!8>D3^]T;K*VD9:(MH6P)KU$%)`R,!
M(GE$"6A@6$A)>43^]VSK!49XL49(,49X1/[WA_T"1@`H3M`X2REI>T0;:`EH
MX%C^]R3K-4L!(CY)>T0;:'E$Y5@H1O[W>NL[2@%&*$9Z1#I-_O<4ZRY+.4A]
M1'M$&V@`(GA$,4;C6(/X:2#^]U[]!$:H8+"Q3_3@<2!&_O=^ZT(<`T81*!B_
M`2HLV"U*(TMZ1--8&F@!FUI`3_```R#1`K!PO6AH__?__`1&J&``*.'1)4AX
M1/[W5.M#>``KA=!^YR)+*FE[1!!H6V@9:/[W]?ZOYP]+>T0;:.!8_O=@ZXSG
M_O>LZAI)(D8:2'E$>$1):`EH_O<TZ[IC``":8P``?F,``%YC```X8P``)F,`
M``1C``"*8@``P&(```0!``!*$```X!$``,P1``"V$0``A`\``(81``".$0``
M=F,``"X/``#`80``,!$```IC``#D8@``&A$``#"U3_2`7*WK#`S,^.@/*4H$
M1BE+@[!Z1"A(:49X1--8&V@!DT_P``/^]]3\<+$#>``K&+\P*PR_`2,`(X/P
M`0,`+`R_`",#\`$#6[D<2AI+>D336!IH`9M:0$_P``,GT0.P,+TC>``K\-`@
M1O_WC/@O(05&_O<8ZP"Q11PH1O[W+.H0200B>43^]R;K`"C=T0U*"4MZ1--8
M&F@!FUI`3_```P71($8#L+WH,$#^]QJ]_O<8ZN)@```$`0``C`X``*A@``#F
M#@``9&`````````MZ?!/3_2`7*WK#`S,^#`-W_@02JWU*WT#1@BI`_&`!]_X
M!#I\1`*0"D9`,``FO$;C6!MHJ9-/\``#4.D"=%9@UF`0,C^Z0O@0?",*)0(#
M]']#"#!#ZA1C!?1_!4/J!&-@14/J!0-"^`@\YM'=Z2*""JPFFPWQB`D`DR2H
M)JT!]0)S`Y`@1@25S>D%00UHS?@<D)%&W?B4X-WXG,`)G]WX++`DGMWX**``
MF0&3`>"21IM&`)$`(]#I#A10^`@O0V=10('J"`&P1D-H:4``GE5&7$"$Z@D$
M\49\0.9&3^K1?$D83.I$#`&<0>H,`5]&3_``#(1"`6?:T0.;`IC=Z05!'6@$
MF]#I`7L;:`.3T.D#.D_JFP[0^`#`"F@A:$[J@WZ$:4?VF1/%]H(C`)0$:M(8
M3^K<8`&40.I'$!(9`)Q`ZDP0W?@<D((8BNH$`$[JBWX`Z@L`W?@P@&!`V?@`
M8!(83^J<"8KJ#@#)&$GJAWD`Z@P`2>J,>0D9@.H*``Z?"!B.Z@D!&.L#"!%`
M`.OR8!CK"@B!Z@X!3^JR`ACK`0'_&!?K#@@!Z_!GB>H"`=WX0.`!0$_JL`"!
MZ@D!&.L!`1[K`PX>ZPD)`>OW;H+J``'=^$B`.4!/ZK<'44`9ZP$!&.L#"!CK
M`@F`Z@<"W?A0@`+J#@(!Z_YA0D!/ZKX.&>L"`ACK`P@8ZP`)`NOQ8(?J#@+=
M^%B`"D!/ZK$!>D`9ZP("&.L#"!CK!PD"Z_!GCNH!`MWX8(`"0$_JL`""Z@X"
M&>L"`ACK`P@8ZPX)`NOW;H'J``+=^&B`.D!/ZK<'2D`9ZP("&.L#"!CK`0D"
MZ_YA@.H'`MWX<(`"Z@X"3^J^#D)`&>L"`ACK`P@8ZP`)`NOQ8(?J#@+=^'B`
M"D!/ZK$!>D`9ZP("&.L#"!CK!PD"Z_!GCNH!`MWX@(`"0$_JL`""Z@X"`YP9
MZP("&.L#"!CK#@X"Z_=H@>H``CI`3^JW!TI`'NL"`O88=AB`Z@<!`>H(`0+K
M^&)!0$_JN`AQ&.T8+1@!Z_)@A^H(`1%`3^JR`HCJ`@9Y0&D8!D`HG>08`>OP
M88;J"`9/ZK``Y!FD&8+J``?M&`]`%>L(!BJ=!.OQ9%=`3^JQ`?89@.H!#NT8
MKQ@.Z@0.+)U/ZK0"CNH`#@;K]&87ZPX$@>H"!^T8-T`M&"Z83T`$Z_9D[QE/
MZK8&PQ@PG5L8@NH&`2%`!^OT;E%`3^JT!%@83O:A,\;VV6,RF17K`P@`Z_Y@
M&.L""(;J!`*"Z@X"3^J^!1CK`@B$Z@4.RA@TGPCK\&&.Z@`.DAE/ZK``$NL.
M`C:>_QB%Z@`.`NOQ8H[J`0X\&4_JL0$4ZPX$.)_V&(#J`0X$Z_)DCNH"#G49
M3^JR`A7K#@4ZGH'J`@[_&([J!`X_&`7K]&`7ZPX'3^JT!!;K`PX\G1[K`0X'
MZ_!A@NH$!T=`3^JP`![K!P[O&#Z>OQ@.Z_%BA.H`#H[J`0Y/ZK$!%^L.!Q;K
M`PY`G1[K!`X'Z_)D@.H!!U=`3^JR`A[K!P[O&$*>/Q@.Z_1@@>H"#H[J!`Y/
MZK0$%^L.!T2=@NH$#O88!^OP9X[J``YV&$_JL``6ZPX&1IF$Z@`.[1@&Z_=F
MCNH'#JT83^JW!Q7K#@5(FLD8@.H'#@7K]F6.Z@8.#!E/ZK8&%.L.!$J9TAB'
MZ@8.!.OU9([J!0X0&$_JM040ZPX`3)J&Z@4.R1@`Z_1@CNH$#LD93^JT!!'K
M#@%.GX7J!`[2&`'K\&&.Z@`.DAE/ZK``$NL.`E">_QB$Z@`.`NOQ8H[J`0Y]
M&4_JL0$5ZPX%4I_V&(#J`0Z.Z@(.-!D4ZPX$!>OR9A?K`PY/ZK("5)T>ZP`.
M@>H"``3K]F1P0![K``Y/ZK8`[1B"Z@`&:1A6G69`#NOT;HD93^JT!.L86)V;
M&(#J!`*"Z@X"3^J^!YH82_;<0\CV&W,!Z_YA[1A$Z@<.6IXH&`[J`0X$Z@<%
M3NH%#@+K\6(0ZPX.3^JQ`?`87)T`&4?J`00.Z_)F%$`'Z@$.3^JR`D3J#@0!
MZ@(()!CM&$'J`@`5ZP<.,$`$Z_9E7IQ`Z@@`3^JV!A#K#@[@&`[K]61`&$+J
M!@$"Z@8.*4!@GT'J#@%/ZK4%"1@!Z_1@_QA&Z@4!!NH%#KH8(4!BGT_JM`1!
MZ@X!!>H$"(D8_QA%Z@0"%^L&#@)`9)\!Z_!A0NH(`D_JL``2ZPX"_Q@$Z@`.
M?1D"Z_%G1.H``F:>"D!/ZK$!0NH.`MWXH.%5&?(8$AE`Z@$$3^JW!@7K]V4\
M0`#J`0<\0T'J!@>B&![K`P0D&`'J!@YJF"]``NOU8D?J#@=/ZK4%/!E&Z@4'
MP!@$Z_)D!NH%#D`8%T!/ZK(!;)I'Z@X'/QA%Z@$`TA@@0)(9!^OT9@7J`0=/
MZK0$.$-!Z@0'@!ANF@'J!`XW0-(8`.OV8%49<)I'Z@X'3^JV!G\9TAA5&`?K
M\&%$Z@8'!.H&#G*:!T!'Z@X'3^JP`'T9TA@2&4;J``0&Z@`'#$`\0P7K\66D
M&'2:3^JQ`03K]632&$#J`0<`Z@$.EADO0'::1^H.!T_JM06_&=(8%A@'Z_1@
M0>H%!P'J!0YXFB=`1^H.!T_JM`2_&47J!`;2&`9`4A@'Z_!A!>H$!T_JL``^
M0P*?MA@`(@3J``X&Z_%F>F#Z8'J:TAA5&0`B>F'Z843J``=\F@]`1^H.!T_J
ML0%_&=(80.H!!0?K]F<2ZP0.-4!/ZK8$?IH`Z@$&-4,!Z@0&%>L.!=,8&QA!
MZ@0`.$"`FC!#!>OW9<`83/+6$\SV8B-/ZK<'UAB"FG88A.H'`6E``.OU8'88
M3^JU!=(8A^H%`109A)I!0`;K\&9D&$_JL`#2&(7J``'7&8::!.OV9'%`?QA/
MZK8&T1B(FDD9!^OT98#J!@=G0$_JM`3)&=<8/QB*FH;J!``!Z_5A:$!/ZK4%
M/QC0&(`9C)H'Z_%FA.H%!T]`3^JQ`<`9UQ@_&8Z:A>H!!`#K]F!T0#\93^JV
M!-88D)IV&0?K\&6!Z@0'1T!/ZK``]AG7&'\8DIH&Z_5AA.H`!FY`3^JU!;\9
MUA@V&92:!^OQ9(#J!0=/0$_JL0'V&=<8/QB6F@;K]&"%Z@$&9D!/ZK0$OQG6
M&'89F)H'Z_!E@>H$!T=`3^JP`/89UQA_&)J:!NOU883J``9N0$_JM06_&=88
M-AF<F@?K\62`Z@4'3T!/ZK$!]AG7&#\8GIH&Z_1@A>H!!F9`3^JT!+\9UAAV
M&:":!^OP98'J!`='0$_JL`#V&=(85Q@&Z_5AHIJ$Z@`&;D!/ZK4%OQG2&!89
M!^OQ9(#J!0>DFD]`3^JQ`?<9`IX'Z_1GTA@0&`KKMP(R8:::A>H!!F9`3^JT
M!(`9TQB!Z@0"`.OW8'I`$^L,`P*?6QF;&!#K"P(#Z_!C`)@[8`&;)!BZ8`Q*
MR1@`(WMB"4MZ1+QA.6+36!IHJ9M:0$_P``,#T0WU*WV]Z/"/_??Z[`"_!&``
M``0!```F5@``"+5/](!<K>L,#,SX^`^`(/WW,NV?[0Y[`"*"9X#M`'N?[0U[
M@.T">Y_M#7N`[01[G^T->X#M!GN?[0U[@.T(>Y_M#7N`[0I[@.T,>PB]`+\!
M(T5G`````(FKS>\`````_MRZF`````!V5#(0`````/#ATL,`````````````
M```MZ?A#3_2`7*WK#`S,^.`/!4:`:A9&`",,1@#KQ@SW%X1%Z&K5Z0PA<^L`
M``+2`3)!\0`!J&\%\3@(Q>D*PW,/0^K'`YL8*V-!ZU=Q:6.`NS\N1=VF\4`)
M3^J9%G<<!.N'%R%&0T8$\4`.T?@`P!`Q4?@,3!`S4?@(#%'X!"QQ14/X$,Q#
M^`Q,0_@(#$/X!"SKT0Q&*$;_]UOZO$+AT:GKAA8R1CE&0$;]]S;LKF>]Z/B#
MP/%`!P7Q.`BW0D!$J+\W1B%&.D;]]RCLJV\[1*MG0"OLT2A&]AL\1/_W.?JW
MYR=&WN<MZ?!!3_2`7*WK#`S,^.@/BVH!\3@'"FL,1I/Z@_@%1L/SQ0,6NED<
M@"(X*?I41=W!\4`">!@`(?WWR.P@1O_W%?HX1C@B`"']]\#L($;$Z1QH__<+
M^N-X*W`@1F.(:W`C:!L*JW`C:.MPXWHK<6.):W&C:!L*JW&C:.MQXWPK<F.*
M:W(C:1L*JW(C:>MRXWXK<V.+:W.C:1L*JW.C:>MSE/@C,"MT8XQK="-J&PJK
M="-JZW2]Z/!!_?>TNW@8P?$X`@`A_?>"[,#G`+\"2WM$&VC]]]N[`+_^5```
M"$`MZ0B`O>@!``(`/@```$$````,````00```!$```!!````)P```$$````V
M````00````,```!!````!@```$$````5````00````\```!!````#@```$$`
M```F````00```!,```!!````*0```$$````"````00```!D```!!````"@``
M`$$````+````00``````````````)7,O)7,````O<')O8R]S96QF+V5X90``
M1'EN84QO861E<CHZ8F]O=%]$>6YA3&]A9&5R`$EN=&5R;F%L<SHZ4$%2.CI"
M3T]4`````"]P<F]C+R5I+R5S`&5X90`N````4$%27U1%35``````4$%27U!2
M3T=.04U%`````#H````E<R5S)7,``"\```!015),-4Q)0@````!015),3$E"
M`%!%4DPU3U!4`````%!%4DQ)3P``4$%27TE.251)04Q)6D5$`%!!4E]34$%7
M3D5$`%!!4E]#3$5!3@```%!!4E]$14)51P```%!!4E]#04-(10```%!!4E]'
M3$]"04Q?1$5"54<`````4$%27T=,3T)!3%]435!$25(```!005)?5$U01$E2
M``!005)?1TQ/0D%,7U1%35``4$%27T=,3T)!3%]#3$5!3@````!L<V5E:R!F
M86EL960`````<F5A9"!F86EL960`3$1?3$E"4D%265]0051(`%-94U1%30``
M)3`R>``````E<R5S)7,E<P````!P87(M`````"5S.B!C<F5A=&EO;B!O9B!P
M<FEV871E('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H``"5S
M.B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!I<R!U;G-A9F4@*'!L96%S92!R
M96UO=F4@:70@86YD(')E=')Y('EO=7(@;W!E<F%T:6]N*0H``%!!5$@`````
M<&%R;``````N<&%R`````'-H;W)T(')E860``"5S)7-C86-H92TE<R5S```E
M<R5S=&5M<"TE=25S````)7,E<W1E;7`M)74M)74E<P`````8````<&5R;```
M```P````4$%2.CI086-K97(Z.E9%4E-)3TX`````,2XP-C$```!5;F%B;&4@
M=&\@8W)E871E(&-A8VAE(&1I<F5C=&]R>0`````E<SH@8W)E871I;VX@;V8@
M<')I=F%T92!C86-H92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE
M:2D*`````"UE```M+0``55-%4@````!54T523D%-10````!414U01$E2`%1-
M4``O=&UP`````&5V86P@)V5X96,@+W5S<B]B:6XO<&5R;"`@+5,@)#`@)'LQ
M*R(D0")])PII9B`P.R`C(&YO="!R=6YN:6YG('5N9&5R('-O;64@<VAE;&P*
M<&%C:V%G92!?7W!A<E]P;#L*;7D@*"1005)?34%'24,L("1&24Q%7V]F9G-E
M=%]S:7IE+"`D8V%C:&5?;F%M95]S:7IE*3L*0D5'24X@>PHD4$%27TU!1TE#
M(#T@(EQN4$%2+G!M7&XB.PHD1DE,15]O9F9S971?<VEZ92`](#0[("`@(R!P
M86-K*").(BD*)&-A8VAE7VYA;65?<VEZ92`](#0P.PHD4$M:25!?34%'24,@
M/2`B4$M<,#`S7#`P-"(["GT*<W5B(&9I;F1?<&%R7VUA9VEC"GL*;7D@*"1F
M:"D@/2!`7SL*;7D@)&-H=6YK7W-I>F4@/2`V-"`J(#$P,C0["FUY("1B=68[
M"FUY("1S:7IE(#T@+7,@)&9H.PIM>2`D<&]S(#T@*"1S:7IE+3$I("T@*"1S
M:7IE+3$I("4@)&-H=6YK7W-I>F4[("`@("`@(R!.3U1%.B`D<&]S(&ES(&$@
M;75L=&EP;&4@;V8@)&-H=6YK7W-I>F4*=VAI;&4@*"1P;W,@/CT@,"D@>PIS
M965K("1F:"P@)'!O<RP@,#L*<F5A9"`D9F@L("1B=68L("1C:'5N:U]S:7IE
M("L@;&5N9W1H*"1005)?34%'24,I.PII9B`H*&UY("1I(#T@<FEN9&5X*"1B
M=68L("1005)?34%'24,I*2`^/2`P*2!["G)E='5R;B`D<&]S("L@)&D["GT*
M)'!O<R`M/2`D8VAU;FM?<VEZ93L*?0IR971U<FX@+3$["GT*;7D@*"1P87)?
M=&5M<"P@)'!R;V=N86UE+"!`=&UP9FEL92P@)4UO9'5L94-A8VAE*3L*14Y$
M('L@:68@*"1%3E9[4$%27T-,14%.?2D@>PIR97%U:7)E($9I;&4Z.E1E;7`[
M"G)E<75I<F4@1FEL93HZ0F%S96YA;64["G)E<75I<F4@1FEL93HZ4W!E8SL*
M;7D@)'1O<&1I<B`]($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1P87)?=&5M
M<"D["F]U=',H<7%;4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?=&5M<")=*3L*
M1FEL93HZ1FEN9#HZ9FEN9&1E<'1H*'-U8B![("@@+60@*2`_(')M9&ER(#H@
M=6YL:6YK('TL("1P87)?=&5M<"D["G)M9&ER("1P87)?=&5M<#L*:68@*"UD
M("1P87)?=&5M<"`F)B`D7D\@;F4@)TU35VEN,S(G*2!["FUY("1T;7`@/2!N
M97<@1FEL93HZ5&5M<"@*5$5-4$Q!5$4@/3X@)W1M<%A86%A8)RP*1$E2(#T^
M($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1T;W!D:7(I+`I3549&25@@/3X@
M)RYC;60G+`I53DQ)3DL@/3X@,"P**3L*;7D@)&9I;&5N86UE(#T@)'1M<"T^
M9FEL96YA;64["G!R:6YT("1T;7`@/#PB+BXN(CL*>#TQ.R!W:&EL92!;(%PD
M>"`M;'0@,3`@73L@9&\*<FT@+7)F("<D<&%R7W1E;7`G"FEF(%L@7"$@+60@
M)R1P87)?=&5M<"<@73L@=&AE;@IB<F5A:PIF:0IS;&5E<"`Q"G@]8&5X<'(@
M7"1X("L@,6`*9&]N90IR;2`G)&9I;&5N86UE)PHN+BX*8VQO<V4@)'1M<#L*
M8VAM;V0@,#<P,"P@)&9I;&5N86UE.PIM>2`D8VUD(#T@(B1F:6QE;F%M92`^
M+V1E=B]N=6QL(#(^)C$@)B(["G-Y<W1E;2@D8VUD*3L*;W5T<RAQ<5M3<&%W
M;F5D(&)A8VMG<F]U;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z("1F
M:6QE;F%M95TI.PI]"GT@?0I"14=)3B!["DEN=&5R;F%L<SHZ4$%2.CI"3T]4
M*"D@:68@9&5F:6YE9"`F26YT97)N86QS.CI005(Z.D)/3U0["F5V86P@>PI?
M<&%R7VEN:71?96YV*"D["FUY("1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT[
M"FUY("5S>7,@/2`H"G!A=&A?<V5P("`@(#T^("@D7D\@/7X@+UY-4U=I;B\@
M/R`G.R<@.B`G.B<I+`I?97AE("`@("`@("`]/B`H)%Y/(#U^("]>*#\Z35-7
M:6Y\3U,R?&-Y9W=I;BDO(#\@)RYE>&4G(#H@)R<I+`I?9&5L:6T@("`@("`]
M/B`H)%Y/(#U^("]>35-7:6Y\3U,R+R`_("=<7"<@.B`G+R<I+`HI.PI?<V5T
M7W!R;V=N86UE*"D["F]U=',H<7%;7"1P<F]G;F%M92`]("(D<')O9VYA;64B
M72D["E]S971?<&%R7W1E;7`H*3L*;W5T<RAQ<5M<)$5.5GM005)?5$5-4'T@
M/2`B)$5.5GM005)?5$5-4'TB72D["FUY("@D<W1A<G1?<&]S+"`D<W1A<G1?
M;V9?1DE,15]S96-T:6]N*3L*34%'24,Z('L*;&]C86P@)%-)1WM?7U=!4DY?
M7WT@/2!S=6(@>WT["G5N;&5S<R`H;W!E;B!?1D@L("<\.G)A=R<L("1P<F]G
M;F%M92D@>PIO=71S*'%Q6T-A;B=T(')E860@9G)O;2!F:6QE("(D<')O9VYA
M;64B72D[("`C(&1O;B=T('5S92`D(2!H97)E(&%S(&ET(')E<75I<F5S($5R
M<FYO+G!M"FQA<W0@34%'24,["GT*;7D@)&UA9VEC7W!O<R`](&9I;F1?<&%R
M7VUA9VEC*"I?1D@I.PII9B`H)&UA9VEC7W!O<R`\(#`I('L*;W5T<RAQ<5M#
M86XG="!F:6YD(&UA9VEC('-T<FEN9R`B)%!!4E]-04=)0R(@:6X@9FEL92`B
M)'!R;V=N86UE(ETI.PIL87-T($U!1TE#.PI]"F]U=',H(D9O=6YD(%!!4B!M
M86=I8R!A="!P;W-I=&EO;B`D;6%G:6-?<&]S(BD["G-E96L@7T9(+"`D;6%G
M:6-?<&]S("T@)$9)3$5?;V9F<V5T7W-I>F4@+2!L96YG=&@H(EPP0T%#2$4B
M*2P@,#L*<F5A9"!?1D@L("1B=68L(&QE;F=T:"@B7#!#04-(12(I.PII9B`H
M)&)U9B!N92`B7#!#04-(12(@)B8@)&)U9B!N92`B7#!#3$5!3B(I('L*;W5T
M<R@B3F\@8V%C:&4@;6%R:V5R(&9O=6YD(BD["FQA<W0@34%'24,["GT*;W5T
M<RAQ<5M#86-H92!M87)K97(@(B1B=68B(&9O=6YD72D["G-E96L@7T9(+"`D
M;6%G:6-?<&]S("T@)$9)3$5?;V9F<V5T7W-I>F4L(#`["G)E860@7T9(+"`D
M8G5F+"`D1DE,15]O9F9S971?<VEZ93L*;7D@)&]F9G-E="`]('5N<&%C:R@B
M3B(L("1B=68I.PIO=71S*")/9F9S970@9G)O;2!S=&%R="!O9B!&24Q%<R!I
M<R`D;V9F<V5T(BD["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F
M<V5T7W-I>F4@+2`D;V9F<V5T+"`P.PHD<W1A<G1?;V9?1DE,15]S96-T:6]N
M(#T@=&5L;"!?1D@["FUY("5R97%U:7)E7VQI<W0["G)E860@7T9(+"`D8G5F
M+"`T.R`@("`@("`@("`@("`@("`@("`@("`@("`@(",@<F5A9"!T:&4@9FER
M<W0@(D9)3$4B"G=H:6QE("@D8G5F(&5Q(")&24Q%(BD@>PIR96%D(%]&2"P@
M)&)U9BP@-#L*<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PIM
M>2`D9G5L;&YA;64@/2`D8G5F.PIO=71S*'%Q6U5N<&%C:VEN9R!&24Q%("(D
M9G5L;&YA;64B+BXN72D["FUY("1C<F,@/2`H("1F=6QL;F%M92`]?B!S?%XH
M6V$M9EQD77LX?2DO?'P@*2`_("0Q(#H@=6YD968["FUY("@D8F%S96YA;64L
M("1E>'0I(#T@*"1B=68@/7X@;7PH/SHN*B\I/R@N*BDH7"XN*BE\*3L*<F5A
M9"!?1D@L("1B=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D
M8G5F*3L*:68@*&1E9FEN960H)&5X="D@86YD("1E>'0@(7X@+UPN*#\Z<&U\
M<&Q\:7A\86PI)"]I*2!["FUY("1F:6QE;F%M92`](%]S879E7V%S*"(D8W)C
M)&5X="(L("1B=68L(#`W-34I.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F
M=6QL;F%M97T@/2`D9FEL96YA;64["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[
M)&9I;&5N86UE?2`]("1F=6QL;F%M93L*?0IE;'-E('L*)$UO9'5L94-A8VAE
M>R1F=6QL;F%M97T@/2!["F)U9B`]/B`D8G5F+`IC<F,@/3X@)&-R8RP*;F%M
M92`]/B`D9G5L;&YA;64L"GT["B1R97%U:7)E7VQI<W1[)&9U;&QN86UE?2LK
M.PI]"G)E860@7T9(+"`D8G5F+"`T.PI]"FQO8V%L($!)3D,@/2`H<W5B('L*
M;7D@*"1S96QF+"`D;6]D=6QE*2`]($!?.PIR971U<FX@:68@<F5F("1M;V1U
M;&4@;W(@(21M;V1U;&4["FUY("1I;F9O(#T@)$UO9'5L94-A8VAE>R1M;V1U
M;&5].PIR971U<FX@=6YL97-S("1I;F9O.PID96QE=&4@)')E<75I<F5?;&ES
M='LD;6]D=6QE?3L*)$E.0WLD;6]D=6QE?2`]("(O;&]A9&5R+R1I;F9O+R1M
M;V1U;&4B.PII9B`H)$5.5GM005)?0TQ%04Y](&%N9"!D969I;F5D*"9)3SHZ
M1FEL93HZ;F5W*2D@>PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W7W1M<&9I;&4@
M;W(@9&EE(")#86XG="!C<F5A=&4@=&5M<"!F:6QE.B`D(2(["B1F:"T^8FEN
M;6]D92@I.PHD9F@M/G!R:6YT*"1I;F9O+3Y[8G5F?2D["B1F:"T^<V5E:R@P
M+"`P*3L*<F5T=7)N("1F:#L*?0IE;'-E('L*;7D@)&9I;&5N86UE(#T@7W-A
M=F5?87,H(B1I;F9O+3Y[8W)C?2YP;2(L("1I;F9O+3Y[8G5F?2D["B1I;F9O
M+3Y[9FEL97T@/2`D9FEL96YA;64["F]P96X@;7D@)&9H+"`G/#IR87<G+"`D
M9FEL96YA;64@;W(@9&EE('%Q6T-A;B=T(')E860@(B1F:6QE;F%M92(Z("0A
M73L*<F5T=7)N("1F:#L*?0ID:64@(D)O;W1S=')A<'!I;F<@9F%I;&5D.B!C
M86XG="!F:6YD(&UO9'5L92`D;6]D=6QE(2(["GTL($!)3D,I.PIR97%U:7)E
M(%A33&]A9&5R.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@0V%R<#HZ
M2&5A=GD["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PI005(Z.DAE879Y.CI?
M:6YI=%]D>6YA;&]A9&5R*"D["G)E<75I<F4@24\Z.D9I;&4["G=H:6QE("AM
M>2`D9FEL96YA;64@/2`H<V]R="!K97ES("5R97%U:7)E7VQI<W0I6S!=*2![
M"G5N;&5S<R`H)$E.0WLD9FEL96YA;65](&]R("1F:6QE;F%M92`]?B`O0E-$
M4$%.+RD@>PII9B`H)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI('L*<F5Q=6ER
M92`D9FEL96YA;64["GT*96QS92!["F1O("1F:6QE;F%M92!U;FQE<W,@)&9I
M;&5N86UE(#U^("]S:71E8W5S=&]M:7IE7"YP;"0O.PI]"GT*9&5L971E("1R
M97%U:7)E7VQI<W1[)&9I;&5N86UE?3L*?0II9B`H)&)U9B!N92`D4$M:25!?
M34%'24,I('L*;W5T<RAQ<5M.;R!Z:7`@9F]U;F0@869T97(@1DE,12!S96-T
M:6]N(&EN(&9I;&4@(B1P<F]G;F%M92)=*3L*;&%S="!-04=)0R`["GT*)'-T
M87)T7W!O<R`]("AT96QL(%]&2"D@+2`T.R`@("`@("`@("`@("`@("`C('-T
M87)T(&]F('II<`I]"FUY($!P87)?87)G<SL*;7D@*"1O=70L("1B=6YD;&4L
M("1L;V=F:"P@)&-A8VAE7VYA;64I.PID96QE=&4@)$5.5GM005)?05!07U)%
M55-%?3L@(R!S86YI=&EZ92`H4D554T4@;6%Y(&)E(&$@<V5C=7)I='D@<')O
M8FQE;2D*:68@*"$D<W1A<G1?<&]S(&]R("@D05)'5ELP72!E<2`G+2UP87(M
M;W!T:6]N<R<@)B8@<VAI9G0I*2!["FUY("5D:7-T7V-M9"`]('%W*`IP("`@
M8FQI8E]T;U]P87(*:2`@(&EN<W1A;&Q?<&%R"G4@("!U;FEN<W1A;&Q?<&%R
M"G,@("!S:6=N7W!A<@IV("`@=F5R:69Y7W!A<@HI.PII9B`H0$%21U8@86YD
M("1!4D=66S!=(&5Q("<M+7)E=7-E)RD@>PIS:&EF="!`05)'5CL*)$5.5GM0
M05)?05!07U)%55-%?2`]('-H:69T($!!4D=6.PI]"F5L<V4@>R`C(&YO<FUA
M;"!P87)L(&)E:&%V:6]U<@IM>2!`861D7W1O7VEN8SL*=VAI;&4@*$!!4D=6
M*2!["B1!4D=66S!=(#U^("]>+2A;04E-3T),8G%P:75S5'9=*2@N*BDO(&]R
M(&QA<W0["FEF("@D,2!E<2`G22<I('L*<'5S:"!`861D7W1O7VEN8RP@)#([
M"GT*96QS:68@*"0Q(&5Q("=-)RD@>PIE=F%L(")U<V4@)#(B.PI]"F5L<VEF
M("@D,2!E<2`G02<I('L*=6YS:&EF="!`<&%R7V%R9W,L("0R.PI]"F5L<VEF
M("@D,2!E<2`G3R<I('L*)&]U="`]("0R.PI]"F5L<VEF("@D,2!E<2`G8B<I
M('L*)&)U;F1L92`]("=S:71E)SL*?0IE;'-I9B`H)#$@97$@)T(G*2!["B1B
M=6YD;&4@/2`G86QL)SL*?0IE;'-I9B`H)#$@97$@)W$G*2!["B1Q=6EE="`]
M(#$["GT*96QS:68@*"0Q(&5Q("=,)RD@>PIO<&5N("1L;V=F:"P@(CX^(BP@
M)#(@;W(@9&EE('%Q6T-A;B=T(&]P96X@;&]G(&9I;&4@(B0R(CH@)"%=.PI]
M"F5L<VEF("@D,2!E<2`G5"<I('L*)&-A8VAE7VYA;64@/2`D,CL*?0IS:&EF
M="A`05)'5BD["FEF("AM>2`D8VUD(#T@)&1I<W1?8VUD>R0Q?2D@>PID96QE
M=&4@)$5.5GLG4$%27U1%35`G?3L*:6YI=%]I;F,H*3L*<F5Q=6ER92!005(Z
M.D1I<W0["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"D@=6YL97-S($!!4D=6.PHF
M>R)005(Z.D1I<W0Z.B1C;60B?2@D7RD@9F]R($!!4D=6.PIE>&ET.PI]"GT*
M=6YS:&EF="!`24Y#+"!`861D7W1O7VEN8SL*?0I]"FEF("@D;W5T*2!["GL*
M<F5Q=6ER92!)3SHZ1FEL93L*<F5Q=6ER92!!<F-H:79E.CI::7`["G)E<75I
M<F4@1&EG97-T.CI32$$["GT*;7D@)'!A<B`]('-H:69T*$!!4D=6*3L*;7D@
M)'II<#L*:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(&UY("1F:"P@)SPZ<F%W
M)RP@)'!A<B!O<B!D:64@<7%;0V%N)W0@9FEN9"!P87(@9FEL92`B)'!A<B(Z
M("0A73L*8FQE<W,H)&9H+"`G24\Z.D9I;&4G*3L*)'II<"`]($%R8VAI=F4Z
M.EII<"T^;F5W.PHH("1Z:7`M/G)E861&<F]M1FEL94AA;F1L92@D9F@L("1P
M87(I(#T]($%R8VAI=F4Z.EII<#HZ05I?3TLH*2`I"F]R(&1I92!Q<5M%<G)O
M<B!R96%D:6YG('II<"!A<F-H:79E("(D<&%R(ET["GT*;7D@)6UE=&%?<&%R
M(#T@9&\@>PII9B`H)'II<"!A;F0@;7D@)&UE=&$@/2`D>FEP+3YC;VYT96YT
M<R@G345402YY;6PG*2D@>PHD;65T82`]?B!S+RXJ7G!A<CHD+R]M<SL*)&UE
M=&$@/7X@<R]>7%,N*B\O;7,["B1M971A(#U^("]>("`H6UXZ72LI.B`H+BLI
M)"]M9SL*?0I].PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@;7D@)'!H+"`G
M/#IR87<G+"`D<&%R(&]R(&1I92!Q<5M#86XG="!R96%D('!A<B!F:6QE("(D
M<&%R(CH@)"%=.PIM>2`D8G5F.PIR96%D("1P:"P@)&)U9BP@-#L*9&EE('%Q
M6R(D<&%R(B!I<R!N;W0@82!P87(@9FEL95T@=6YL97-S("1B=68@97$@)%!+
M6DE07TU!1TE#.PIC;&]S92`D<&@["GT*0W)E871E4&%T:"@D;W5T*2`["FUY
M("1F:"`]($E/.CI&:6QE+3YN97<H"B1O=70L"DE/.CI&:6QE.CI/7T-214%4
M*"D@?"!)3SHZ1FEL93HZ3U]21%=2*"D@?"!)3SHZ1FEL93HZ3U]44E5.0R@I
M+`HP-S<W+`HI(&]R(&1I92!Q<5M#86XG="!C<F5A=&4@9FEL92`B)&]U="(Z
M("0A73L*)&9H+3YB:6YM;V1E*"D["G-E96L@7T9(+"`P+"`P.PIM>2`D;&]A
M9&5R.PII9B`H9&5F:6YE9"`D<W1A<G1?;V9?1DE,15]S96-T:6]N*2!["G)E
M860@7T9(+"`D;&]A9&5R+"`D<W1A<G1?;V9?1DE,15]S96-T:6]N.PI](&5L
M<V4@>PIL;V-A;"`D+R`]('5N9&5F.PHD;&]A9&5R(#T@/%]&2#X["GT*:68@
M*"$D14Y6>U!!4E]615)"051)37T@86YD("1L;V%D97(@/7X@+UXH/SHC(7Q<
M0')E;2DO*2!["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PI005(Z
M.D9I;'1E<CHZ4&]D4W1R:7`M/F%P<&QY*%PD;&]A9&5R+"`D,"D["GT*)&9H
M+3YP<FEN="@D;&]A9&5R*0IO<B!D:64@<7%;17)R;W(@=W)I=&EN9R!L;V%D
M97(@=&\@(B1O=70B.B`D(5T["FEF("@D8G5N9&QE*2!["G)E<75I<F4@4$%2
M.CI(96%V>3L*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PII;FET
M7VEN8R@I.PIR97%U:7)E7VUO9'5L97,H*3L*;7D@0&EN8R`](&=R97`@>R`A
M+T)31%!!3B\@?0IG<F5P('L**"1B=6YD;&4@;F4@)W-I=&4G*2!O<@HH)%\@
M;F4@)$-O;F9I9SHZ0V]N9FEG>V%R8VAL:6)E>'!](&%N9`HD7R!N92`D0V]N
M9FEG.CI#;VYF:6=[<')I=FQI8F5X<'TI.PI]($!)3D,["G-\+RM\+WQG+"!S
M?"\D?'P@9F]R96%C:"!`:6YC.PIM>2`E9FEL97,["B1F:6QE<WLD7WTK*R!F
M;W(@0$1Y;F%,;V%D97(Z.F1L7W-H87)E9%]O8FIE8W1S+"!V86QU97,@)4E.
M0SL*;7D@)&QI8E]E>'0@/2`D0V]N9FEG.CI#;VYF:6=[;&EB7V5X='T[("`@
M("`@("`@(R!86%@@;&EB7V5X="!V<R!D;&5X="`_"FUY("5W<FET=&5N.PIF
M;W)E86-H(&UY("1K97D@*'-O<G0@:V5Y<R`E9FEL97,I('L*;7D@*"1F:6QE
M+"`D;F%M92D["FEF("AD969I;F5D*&UY("1F8R`]("1005(Z.DAE879Y.CI&
M=6QL0V%C:&5[)&ME>7TI*2!["B@D9FEL92P@)&YA;64I(#T@*"1K97DL("1F
M8RD["GT*96QS92!["F9O<F5A8V@@;7D@)&1I<B`H0&EN8RD@>PII9B`H)&ME
M>2`]?B!M?%Y<421D:7)<12\H+BHI)'QI*2!["B@D9FEL92P@)&YA;64I(#T@
M*"1K97DL("0Q*3L*;&%S=#L*?0II9B`H)&ME>2`]?B!M?%XO;&]A9&5R+UM>
M+UTK+R@N*BDD?"D@>PII9B`H;7D@)')E9B`]("1-;V1U;&5#86-H97LD,7TI
M('L**"1F:6QE+"`D;F%M92D@/2`H)')E9BP@)#$I.PIL87-T.PI]"FEF("@M
M9B`B)&1I<B\D,2(I('L**"1F:6QE+"`D;F%M92D@/2`H(B1D:7(O)#$B+"`D
M,2D["FQA<W0["GT*?0I]"GT*;F5X="!U;FQE<W,@9&5F:6YE9"`D;F%M93L*
M;F5X="!I9B`D=W)I='1E;GLD;F%M97TK*SL*;F5X="!I9B`A<F5F*"1F:6QE
M*2!A;F0@)&9I;&4@/7X@+UPN7%$D;&EB7V5X=%Q%)"]I.PIO=71S*'-P<FEN
M=&8H<7%;4&%C:VEN9R!&24Q%("(E<R(N+BY=+"!R968@)&9I;&4@/R`D9FEL
M92T^>VYA;65](#H@)&9I;&4I*3L*;7D@)&-O;G1E;G0["FEF("AR968H)&9I
M;&4I*2!["B1C;VYT96YT(#T@)&9I;&4M/GMB=69].PI]"F5L<V4@>PIL;V-A
M;"`D+R`]('5N9&5F.PIO<&5N(&UY("1T:"P@)SPZ<F%W)RP@)&9I;&4@;W(@
M9&EE('%Q6T-A;B=T(')E860@(B1F:6QE(CH@)"%=.PHD8V]N=&5N="`](#PD
M=&@^.PIC;&]S92`D=&@["E!!4CHZ1FEL=&5R.CI0;V13=')I<"T^87!P;'DH
M7"1C;VYT96YT+"`B/&5M8F5D9&5D/B\D;F%M92(I"FEF("$D14Y6>U!!4E]6
M15)"051)37T@86YD("1N86UE(#U^("]<+B@_.G!M?&EX?&%L*20O:3L*4$%2
M.CI&:6QT97(Z.E!A=&-H0V]N=&5N="T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L
M("1F:6QE+"`D;F%M92D["GT*)&9H+3YP<FEN="@B1DE,12(L"G!A8VLH)TXG
M+"!L96YG=&@H)&YA;64I("L@.2DL"G-P<FEN=&8H(B4P.'@O)7,B+"!!<F-H
M:79E.CI::7`Z.F-O;7!U=&5#4D,S,B@D8V]N=&5N="DL("1N86UE*2P*<&%C
M:R@G3B<L(&QE;F=T:"@D8V]N=&5N="DI+`HD8V]N=&5N="D*;W(@9&EE('%Q
M6T5R<F]R('=R:71I;F<@96UB961D960@1DE,12!T;R`B)&]U="(Z("0A73L*
M;W5T<RAQ<5M7<FET=&5N(&%S("(D;F%M92)=*3L*?0I]"FEF("@D>FEP*2![
M"B1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE*"1F:"D@/3T@07)C:&EV93HZ6FEP
M.CI!6E]/2PIO<B!D:64@<7%;17)R;W(@=W)I=&EN9R!Z:7`@<&%R="!O9B`B
M)&]U=")=.PI]"FEF("@D;65T85]P87)[8VQE86Y]*2!["B1F:"T^<')I;G0H
M(EPP0TQ%04XB*3L*?0IE;'-E('L*:68@*"%D969I;F5D("1C86-H95]N86UE
M*2!["FUY("1C='@@/2!$:6=E<W0Z.E-(02T^;F5W*#$I.PIS965K("1F:"P@
M,"P@,#L*)&-T>"T^861D9FEL92@D9F@I.PIS965K("1F:"P@,"P@,CL*)&-A
M8VAE7VYA;64@/2`D8W1X+3YH97AD:6=E<W0["GT*)&-A8VAE7VYA;64@/2!S
M=6)S='(@)&-A8VAE7VYA;64L(#`L("1C86-H95]N86UE7W-I>F4["B1C86-H
M95]N86UE("X](")<,"(@>"`H)&-A8VAE7VYA;65?<VEZ92`M(&QE;F=T:"`D
M8V%C:&5?;F%M92D["B1F:"T^<')I;G0H)&-A8VAE7VYA;64L"B)<,$-!0TA%
M(BD["GT*;7D@)&]F9G-E="`]("1F:"T^=&5L;"`M(&QE;F=T:"@D;&]A9&5R
M*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@)&]F9G-E="DL"B1005)?34%'24,I
M.PHD9F@M/F-L;W-E(&]R(&1I92!Q<5M%<G)O<B!W<FET:6YG('1R86EL97(@
M;V8@(B1O=70B.B`D(5T["F-H;6]D(#`W-34L("1O=70["F5X:70["GT*>PIL
M87-T('5N;&5S<R!D969I;F5D("1S=&%R=%]P;W,["E]F:7A?<')O9VYA;64H
M*3L*<F5Q=6ER92!005(["E!!4CHZ2&5A=GDZ.E]I;FET7V1Y;F%L;V%D97(H
M*3L*>PIR97%U:7)E($9I;&4Z.D9I;F0["G)E<75I<F4@07)C:&EV93HZ6FEP
M.PI]"FUY("1F:"`]($E/.CI&:6QE+3YN97<[("`@("`@("`@("`@("`@("`@
M("`@("`@("`@("`C($%R8VAI=F4Z.EII<"!O<&5R871E<R!O;B!A;B!)3SHZ
M2&%N9&QE"B1F:"T^9F1O<&5N*&9I;&5N;RA?1D@I+"`G<B<I(&]R(&1I92!Q
M<5MF9&]P96XH*2!F86EL960Z("0A73L*07)C:&EV93HZ6FEP.CIS971#:'5N
M:U-I>F4H+7,@7T9(*3L*;7D@)'II<"`]($%R8VAI=F4Z.EII<"T^;F5W.PHH
M)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!R;V=N86UE*2`]/2!!
M<F-H:79E.CI::7`Z.D%:7T]+*"DI"F]R(&1I92!Q<5M%<G)O<B!R96%D:6YG
M('II<"!A<F-H:79E("(D<')O9VYA;64B73L*07)C:&EV93HZ6FEP.CIS971#
M:'5N:U-I>F4H-C0@*B`Q,#(T*3L*<'5S:"!`4$%2.CI,:6)#86-H92P@)'II
M<#L*)%!!4CHZ3&EB0V%C:&5[)'!R;V=N86UE?2`]("1Z:7`["F]U=',H(D5X
M=')A8W1I;F<@>FEP+BXN(BD["FEF("AD969I;F5D("1%3E9[4$%27U1%35!]
M*2![(",@<VAO=6QD(&)E('-E="!A="!T:&ES('!O:6YT(0IF;W)E86-H(&UY
M("1M96UB97(@*"`D>FEP+3YM96UB97)S("D@>PIN97AT(&EF("1M96UB97(M
M/FES1&ER96-T;W)Y.PIM>2`D;65M8F5R7VYA;64@/2`D;65M8F5R+3YF:6QE
M3F%M93L*;F5X="!U;FQE<W,@)&UE;6)E<E]N86UE(#U^(&U["EX*+S]S:&QI
M8B\**#\Z)$-O;F9I9SHZ0V]N9FEG>V%R8VAN86UE?2\I/PHH6UXO72LI"B0*
M?7@["FUY("1E>'1R86-T7VYA;64@/2`D,3L*;7D@)&1E<W1?;F%M92`]($9I
M;&4Z.E-P96,M/F-A=&9I;&4H)$5.5GM005)?5$5-4'TL("1E>'1R86-T7VYA
M;64I.PII9B`H+68@)&1E<W1?;F%M92`F)B`M<R!?(#T]("1M96UB97(M/G5N
M8V]M<')E<W-E9%-I>F4H*2D@>PIO=71S*'%Q6U-K:7!P:6YG("(D;65M8F5R
M7VYA;64B('-I;F-E(&ET(&%L<F5A9'D@97AI<W1S(&%T("(D9&5S=%]N86UE
M(ETI.PI](&5L<V4@>PIO=71S*'%Q6T5X=')A8W1I;F<@(B1M96UB97)?;F%M
M92(@=&\@(B1D97-T7VYA;64B+BXN72D["B@D;65M8F5R+3YE>'1R86-T5&]&
M:6QE3F%M960H)&1E<W1?;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I
M*0IO<B!D:64@<7%;17)R;W(@97AT<F%C=&EN9R!Z:7`@;65M8F5R('1O("(D
M9&5S=%]N86UE(ET["F-H;6]D*#`U-34L("1D97-T7VYA;64I(&EF("1>3R!E
M<2`B:'!U>"(["GT*?0I]"GT*=6YL97-S("@D4$%2.CI,:6)#86-H97LD<')O
M9VYA;65]*2!["F1I92`\/"`B+B(@=6YL97-S($!!4D=6.PI5<V%G93H@)#`@
M6R`M06QI8BYP87(@72!;("U)9&ER(%T@6R`M36UO9'5L92!=(%L@<W)C+G!A
M<B!=(%L@<')O9W)A;2YP;"!="B0P(%L@+4)\+6(@72!;+4]O=71F:6QE72!S
M<F,N<&%R"BX*)$5.5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE(#T@)#`@
M/2!S:&EF="A`05)'5BD["GT*<W5B($-R96%T95!A=&@@>PIM>2`H)&YA;64I
M(#T@0%\["G)E<75I<F4@1FEL93HZ0F%S96YA;64["FUY("@D8F%S96YA;64L
M("1P871H+"`D97AT*2`]($9I;&4Z.D)A<V5N86UE.CIF:6QE<&%R<V4H)&YA
M;64L("@G7"XN*B<I*3L*<F5Q=6ER92!&:6QE.CI0871H.PI&:6QE.CI0871H
M.CIM:W!A=&@H)'!A=&@I('5N;&5S<R@M92`D<&%T:"D[(",@;6MP871H(&1I
M97,@=VET:"!E<G)O<@I]"G-U8B!R97%U:7)E7VUO9'5L97,@>PIR97%U:7)E
M(&QI8CL*<F5Q=6ER92!$>6YA3&]A9&5R.PIR97%U:7)E(&EN=&5G97(["G)E
M<75I<F4@<W1R:6-T.PIR97%U:7)E('=A<FYI;F=S.PIR97%U:7)E('9A<G,[
M"G)E<75I<F4@0V%R<#L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%
M<G)N;SL*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["G)E<75I<F4@17AP;W)T
M97(["G)E<75I<F4@1F-N=&P["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER
M92!&:6QE.CI3<&5C.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E($-O;F9I
M9SL*<F5Q=6ER92!)3SHZ2&%N9&QE.PIR97%U:7)E($E/.CI&:6QE.PIR97%U
M:7)E($-O;7!R97-S.CI:;&EB.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q
M=6ER92!$:6=E<W0Z.E-(03L*<F5Q=6ER92!005(["G)E<75I<F4@4$%2.CI(
M96%V>3L*<F5Q=6ER92!005(Z.D1I<W0["G)E<75I<F4@4$%2.CI&:6QT97(Z
M.E!O9%-T<FEP.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0[
M"G)E<75I<F4@871T<FEB=71E<SL*979A;"![(')E<75I<F4@0W=D('T["F5V
M86P@>R!R97%U:7)E(%=I;C,R('T["F5V86P@>R!R97%U:7)E(%-C86QA<CHZ
M571I;"!].PIE=F%L('L@<F5Q=6ER92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@
M?3L*979A;"![(')E<75I<F4@5&EE.CI(87-H.CI.86UE9$-A<'1U<F4@?3L*
M979A;"![(')E<75I<F4@4&5R;$E/.R!R97%U:7)E(%!E<FQ)3SHZ<V-A;&%R
M('T["F5V86P@>R!R97%U:7)E('5T9C@@?3L*?0IS=6(@7W-E=%]P87)?=&5M
M<"!["FEF("AD969I;F5D("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]4
M14U0?2`]?B`O*"XK*2\I('L*)'!A<E]T96UP(#T@)#$["G)E='5R;CL*?0IF
M;W)E86-H(&UY("1P871H("@**&UA<"`D14Y6>R1??2P@<7<H(%!!4E]435!$
M25(@5$U01$E2(%1%35!$25(@5$5-4"!435`@*2DL"G%W*"!#.EQ<5$5-4"`O
M=&UP("X@*0HI('L*;F5X="!U;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@
M)'!A=&@@86YD("UW("1P871H.PIM>2`D=7-E<FYA;64["FUY("1P=W5I9#L*
M979A;"![*"1P=W5I9"D@/2!G971P=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM]
M.PII9B`H(&1E9FEN960H)E=I;C,R.CI,;V=I;DYA;64I("D@>PHD=7-E<FYA
M;64@/2`F5VEN,S(Z.DQO9VEN3F%M93L*?0IE;'-I9B`H9&5F:6YE9"`D<'=U
M:60I('L*)'5S97)N86UE(#T@)'!W=6ED.PI]"F5L<V4@>PHD=7-E<FYA;64@
M/2`D14Y6>U5315).04U%?2!\?"`D14Y6>U5315)]('Q\("=365-414TG.PI]
M"FUY("1S=&UP9&ER(#T@(B1P871H)'-Y<WM?9&5L:6U]<&%R+2(N=6YP86-K
M*")(*B(L("1U<V5R;F%M92D["FUK9&ER("1S=&UP9&ER+"`P-S4U.PIM>2`D
M8V%C:&5?9&ER.PII9B`H)$5.5GM005)?0TQ%04Y]*2!["B1C86-H95]D:7(@
M/2`B=&5M<"TD)"(["GT*96QS92!["F]P96X@;7D@)&9H+"`B/#IR87<B+"`D
M<')O9VYA;64@;W(@9&EE('%Q6T-A;B=T(')E860@(B1P<F]G;F%M92(Z("0A
M73L*:68@*"AM>2`D;6%G:6-?<&]S(#T@9FEN9%]P87)?;6%G:6,H)&9H*2D@
M/CT@,"D@>PIS965K("1F:"P@)&UA9VEC7W!O<PHM("1&24Q%7V]F9G-E=%]S
M:7IE"BT@;&5N9W1H*")<,$-!0TA%(BDL(#`["FUY("1B=68["G)E860@)&9H
M+"`D8G5F+"!L96YG=&@H(EPP0T%#2$4B*3L*:68@*"1B=68@97$@(EPP0T%#
M2$4B*2!["G-E96L@)&9H+"`D;6%G:6-?<&]S"BT@)$9)3$5?;V9F<V5T7W-I
M>F4*+2!L96YG=&@H(EPP0T%#2$4B*0HM("1C86-H95]N86UE7W-I>F4L(#`[
M"G)E860@)&9H+"`D8G5F+"`D8V%C:&5?;F%M95]S:7IE.PHD8G5F(#U^(',O
M7#`O+V<["B1C86-H95]D:7(@/2`B8V%C:&4M)&)U9B(["GT*?0IC;&]S92`D
M9F@["GT*:68@*"$D8V%C:&5?9&ER*2!["B1C86-H95]D:7(@/2`B=&5M<"TD
M)"(["B1%3E9[4$%27T-,14%.?2`](#$["GT*)'-T;7!D:7(@+CT@(B1S>7-[
M7V1E;&EM?21C86-H95]D:7(B.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*)$5.
M5GM005)?5$5-4'T@/2`D<W1M<&1I<CL*;&%S=#L*?0HD<&%R7W1E;7`@/2`D
M,2!I9B`D14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N
M*RDO.PI]"G-U8B!?<V%V95]A<R!["FUY("@D;F%M92P@)&-O;G1E;G1S+"`D
M;6]D92D@/2!`7SL*;7D@)&9U;&QN86UE(#T@(B1P87)?=&5M<"\D;F%M92([
M"G5N;&5S<R`H+64@)&9U;&QN86UE*2!["FUY("1T96UP;F%M92`]("(D9G5L
M;&YA;64N)"0B.PIM>2`D9F@["BAO<&5N("1F:"P@)SXZ<F%W)RP@)'1E;7!N
M86UE*0HF)B`H<')I;G0@)&9H("1C;VYT96YT<RD*)B8@*&-L;W-E("1F:"D*
M;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@(B1T96UP;F%M92(Z("0A73L*8VAM
M;V0@)&UO9&4L("1T96UP;F%M92!I9B!D969I;F5D("1M;V1E.PIR96YA;64H
M)'1E;7!N86UE+"`D9G5L;&YA;64I(&]R('5N;&EN:R@D=&5M<&YA;64I.PI]
M"G)E='5R;B`D9G5L;&YA;64["GT*<W5B(%]S971?<')O9VYA;64@>PII9B`H
M9&5F:6YE9"`D14Y6>U!!4E]04D]'3D%-17T@86YD("1%3E9[4$%27U!23T=.
M04U%?2`]?B`O*"XK*2\I('L*)'!R;V=N86UE(#T@)#$["GT*)'!R;V=N86UE
M('Q\/2`D,#L*:68@*"1%3E9[4$%27U1%35!](&%N9"!I;F1E>"@D<')O9VYA
M;64L("1%3E9[4$%27U1%35!]*2`^/2`P*2!["B1P<F]G;F%M92`]('-U8G-T
M<B@D<')O9VYA;64L(')I;F1E>"@D<')O9VYA;64L("1S>7-[7V1E;&EM?2D@
M*R`Q*3L*?0II9B`H(21%3E9[4$%27U!23T=.04U%?2!O<B!I;F1E>"@D<')O
M9VYA;64L("1S>7-[7V1E;&EM?2D@/CT@,"D@>PII9B`H;W!E;B!M>2`D9F@L
M("<\)RP@)'!R;V=N86UE*2!["G)E='5R;B!I9B`M<R`D9F@["GT*:68@*"US
M("(D<')O9VYA;64D<WES>U]E>&5](BD@>PHD<')O9VYA;64@+CT@)'-Y<WM?
M97AE?3L*<F5T=7)N.PI]"GT*9F]R96%C:"!M>2`D9&ER("AS<&QI="`O7%$D
M<WES>W!A=&A?<V5P?5Q%+RP@)$5.5GM0051(?2D@>PIN97AT(&EF(&5X:7-T
M<R`D14Y6>U!!4E]414U0?2!A;F0@)&1I<B!E<2`D14Y6>U!!4E]414U0?3L*
M)&1I<B`]?B!S+UQ1)'-Y<WM?9&5L:6U]7$4D+R\["B@H)'!R;V=N86UE(#T@
M(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64D<WES>U]E>&5](BDL(&QA<W0I
M"FEF("US("(D9&ER)'-Y<WM?9&5L:6U])'!R;V=N86UE)'-Y<WM?97AE?2([
M"B@H)'!R;V=N86UE(#T@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64B*2P@
M;&%S="D*:68@+7,@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64B.PI]"GT*
M<W5B(%]F:7A?<')O9VYA;64@>PHD,"`]("1P<F]G;F%M92!\?#T@)$5.5GM0
M05)?4%)/1TY!345].PII9B`H:6YD97@H)'!R;V=N86UE+"`D<WES>U]D96QI
M;7TI(#P@,"D@>PHD<')O9VYA;64@/2`B+B1S>7-[7V1E;&EM?21P<F]G;F%M
M92(["GT*;7D@)'!W9"`]("AD969I;F5D("9#=V0Z.F=E=&-W9"D@/R!#=V0Z
M.F=E=&-W9"@I"CH@*"AD969I;F5D("97:6XS,CHZ1V5T0W=D*2`_(%=I;C,R
M.CI'971#=V0H*2`Z(&!P=V1@*3L*8VAO;7`H)'!W9"D["B1P<F]G;F%M92`]
M?B!S+UXH/SU<+EPN/UQ1)'-Y<WM?9&5L:6U]7$4I+R1P=V0D<WES>U]D96QI
M;7TO.PHD14Y6>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64["GT*<W5B(%]P
M87)?:6YI=%]E;G8@>PII9B`H("1%3E9[4$%27TE.251)04Q)6D5$?2LK(#T]
M(#$@*2!["G)E='5R;CL*?2!E;'-E('L*)$5.5GM005)?24Y)5$E!3$E:141]
M(#T@,CL*?0IF;W(@*'%W*"!34$%73D5$(%1%35`@0TQ%04X@1$5"54<@0T%#
M2$4@4%)/1TY!344@*2`I('L*9&5L971E("1%3E9[(E!!4E\D7R)].PI]"F9O
M<B`H<7<O(%1-4$1)4B!414U0($-,14%.($1%0E5'("\I('L*)$5.5GLB4$%2
M7R1?(GT@/2`D14Y6>R)005)?1TQ/0D%,7R1?(GT@:68@97AI<W1S("1%3E9[
M(E!!4E]'3$]"04Q?)%\B?3L*?0II9B`H)$5.5GM005)?5$5-4'TI('L*9&5L
M971E("1%3E9[4$%27T-,14%.?3L*?0I]"G-U8B!O=71S('L*<F5T=7)N(&EF
M("1Q=6EE=#L*:68@*"1L;V=F:"D@>PIP<FEN="`D;&]G9F@@(D!?7&XB.PI]
M"F5L<V4@>PIP<FEN="`B0%]<;B(["GT*?0IS=6(@:6YI=%]I;F,@>PIR97%U
M:7)E($-O;F9I9SL*<'5S:"!`24Y#+"!G<F5P(&1E9FEN960L(&UA<"`D0V]N
M9FEG.CI#;VYF:6=[)%]]+"!Q=R@*87)C:&QI8F5X<"!P<FEV;&EB97AP('-I
M=&5A<F-H97AP('-I=&5L:6)E>'`*=F5N9&]R87)C:&5X<"!V96YD;W)L:6)E
M>'`**3L*?0IP86-K86=E(&UA:6X["G)E<75I<F4@4$%2.PIU;G-H:69T($!)
M3D,L(%PF4$%2.CIF:6YD7W!A<CL*4$%2+3YI;7!O<G0H0'!A<E]A<F=S*3L*
M9&EE('%Q6W!A<BYP;#H@0V%N)W0@;W!E;B!P97)L('-C<FEP="`B)'!R;V=N
M86UE(CH@3F\@<W5C:"!F:6QE(&]R(&1I<F5C=&]R>5QN70IU;FQE<W,@+64@
M)'!R;V=N86UE.PID;R`D<')O9VYA;64["D-/4D4Z.F5X:70H)#$I(&EF("@D
M0"`]?B]>7U1+7T58251?7"@H7&0K*5PI+RD["F1I92`D0"!I9B`D0#L*?3L*
M)#HZ7U]%4E)/4B`]("1`(&EF("1`.PI]"D-/4D4Z.F5X:70H)#$I(&EF("@D
M.CI?7T524D]2(#U^+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("0Z.E]?
M15)23U(@:68@)#HZ7U]%4E)/4CL*,3L*7U]%3D1?7PH`<&5R;'AS:2YC````
M`$-!0TA%```^````00````P```!!````$0```$$````G````00```#8```!!
M`````P```$$````&````00```!4```!!````#P```$$````.````00```"8`
M``!!````$P```$$````I````00````(```!!````&0```$$````*````00``
M``L```!!``````````````"<F?]_`0``````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````*$7``!A%P```0```"H#```!````.@,```$```!$`P``
M#````,P1```-````$#L``!D```"\C0``&P````0````:````P(T``!P````$
M````]?[_;[0!```%````,`D```8```"@`@``"@```+\$```+````$````!4`
M`````````P```,R.```"````X`$``!0````1````%P```.P/```1````%`\`
M`!(```#8````$P````@````>````"````/O__V\!```(_O__;\0.``#___]O
M`@```/#__V_P#0``^O__;PX`````````````````````````````````````
M````````````````````Q(T`````````````V!$``-@1``#8$0``V!$``-@1
M``#8$0``V!$``-@1``#8$0``V!$``-@1``#8$0``V!$``-@1``#8$0``V!$`
M`-@1``#8$0``V!$``-@1``#8$0``V!$``-@1``#8$0``V!$``-@1``#8$0``
MV!$``-@1``#8$0``V!$``-@1``#8$0``V!$``-@1``#8$0``V!$``-@1``#8
M$0``V!$``-@1``#8$0``V!$``-@1``#8$0``V!$``-@1``#8$0``V!$``-@1
M``#8$0``V!$``-@1``#8$0``V!$``-@1``#8$0``V!$``-@1``#8$0``````
M`````````````````````````````````````````````````-$4````````
M````````````````!)````I005(N<&T*`````/`^```(/````````,@\``#,
M/```Y#X``!`\``#L/@```````-`^``#8/@```````/@^``!'0T,Z("A$96)I
M86X@,3,N,BXP+3$V+C$I(#$S+C(N,`!!,@```&%E86)I``$H````!3<M00`&
M"@=!"`$)`@H$$@03`10!%0$7`Q@!&0$:`AP!(@$`+G-H<W1R=&%B`"YI;G1E
M<G``+FYO=&4N9VYU+F)U:6QD+6ED`"YN;W1E+D%"22UT86<`+F=N=2YH87-H
M`"YD>6YS>6T`+F1Y;G-T<@`N9VYU+G9E<G-I;VX`+F=N=2YV97)S:6]N7W(`
M+G)E;"YD>6X`+G)E;"YP;'0`+FEN:70`+G1E>'0`+F9I;FD`+G)O9&%T80`N
M05)-+F5X:61X`"YE:%]F<F%M90`N:6YI=%]A<G)A>0`N9FEN:5]A<G)A>0`N
M9'EN86UI8P`N9V]T`"YD871A`"YB<W,`+F-O;6UE;G0`+D%232YA='1R:6)U
M=&5S````````````````````````````````````````````````````````
M```+`````0````(```!4`0``5`$``!D```````````````$`````````$P``
M``<````"````<`$``'`!```D```````````````$`````````"8````'````
M`@```)0!``"4`0``(```````````````!``````````T````]O__;P(```"T
M`0``M`$``.P````%``````````0````$````/@````L````"````H`(``*`"
M``"0!@``!@````,````$````$````$8````#`````@```#`)```P"0``OP0`
M`````````````0````````!.````____;P(```#P#0``\`T``-(````%````
M``````(````"````6P```/[__V\"````Q`X``,0.``!0````!@````(````$
M`````````&H````)`````@```!0/```4#P``V`````4`````````!`````@`
M``!S````"0```$(```#L#P``[`\``.`!```%````%0````0````(````?```
M``$````&````S!$``,P1```,```````````````$`````````'<````!````
M!@```-@1``#8$0``]`(`````````````!`````0```""`````0````8```#0
M%```T!0``$`F``````````````@`````````B`````$````&````$#L``!`[
M```(```````````````$`````````(X````!`````@```!@[```8.P``]$$`
M````````````!`````````"6`````0``<((````,?0``#'T```@````-````
M``````0`````````H0````$````"````%'T``!1]```$```````````````$
M`````````*L````.`````P```+R-``"\?0``!```````````````!`````0`
M``"W````#P````,```#`C0``P'T```0```````````````0````$````PP``
M``8````#````Q(T``,1]```(`0``!@`````````$````"````,P````!````
M`P```,R.``#,?@``-`$`````````````!`````0```#1`````0````,`````
MD````(```$@```````````````0`````````UP````@````#````2)```$B`
M```4```````````````$`````````-P````!````,`````````!(@```(0``
M`````````````0````$```#E`````P``<```````````:8```#,`````````
M``````$``````````0````,``````````````)R```#U```````````````!
'````````````
